<?php
/**
 * kimono functions and definitions
 *
 * @package kimono
 */
/**
 * Custom template tags for this theme.
 */
require( get_template_directory() . '/inc/template-tags.php' );

/**
 * Custom functions that act independently of the theme templates
 */
require( get_template_directory() . '/inc/extras.php' );

/**
 * Customizer additions
 */
require( get_template_directory() . '/inc/customizer.php' );


/*
 * Load Jetpack compatibility file.
 */
require( get_template_directory() . '/inc/jetpack.php' );

if ( ! function_exists( 'kimono_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function kimono_setup() {
	
/**
 * Set the content width based on the theme's design and stylesheet.
 */
global $content_width;
if ( ! isset( $content_width ) )
	$content_width = 700; /* pixels */

	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on kimono, use a find and replace
	 * to change 'kimono' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'kimono', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Enable support for Post Thumbnails on posts and pages
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	/**
	 * Enable support for Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );
	set_post_thumbnail_size( 320, 230, true );
}
endif; // kimono_setup
add_action( 'after_setup_theme', 'kimono_setup' );

/**
 * Setup the WordPress core custom background feature.
 *
 * Use add_theme_support to register support for WordPress 3.4+
 * as well as provide backward compatibility for WordPress 3.3
 * using feature detection of wp_get_theme() which was introduced
 * in WordPress 3.4.
 *
 * @todo Remove the 3.3 support when WordPress 3.6 is released.
 *
 * Hooks into the after_setup_theme action.
 */


/**
 * Register widgetized area and update sidebar with default widgets
 */
function kimono_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'kimono' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}

add_action( 'widgets_init', 'kimono_widgets_init' );

/**
 * Enqueue scripts and styles
 */
function kimono_scripts() {

	wp_enqueue_style( 'kimono-style', get_stylesheet_uri() );
	wp_enqueue_style( 'bxslider-style', get_template_directory_uri() . '/css/jquery.bxslider.css' );
	wp_enqueue_script( 'bxslider', get_template_directory_uri() . '/js/jquery.bxslider.min.js', array('jquery'), '' );
	wp_enqueue_script( 'ah-placeholder', get_template_directory_uri() . '/js/jquery.ah-placeholder.js', array(), '' );
	wp_enqueue_script( 'kimono-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array() );

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'kimono-keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
	}
	
	wp_enqueue_script(
    'kimono_function',
    get_template_directory_uri() . '/js/cs.js', 
    array('jquery') 
); 


}
add_action( 'wp_enqueue_scripts', 'kimono_scripts' );

function kimono_new_excerpt_mblength($length) {
     return 180;
}
add_filter('excerpt_length', 'kimono_new_excerpt_mblength');

function kimono_new_excerpt_more($post) {
	
    return ' ...<a class="readmore" href="'. esc_url( get_permalink() ) . '">' . 'далее' . '</a>';	
}	
add_filter('excerpt_more', 'kimono_new_excerpt_more');

add_filter( "comment_form_defaults", "kimono_my_comment_notes_after");

function kimono_my_comment_notes_after($defaults){
  $defaults['comment_notes_after'] = '';
  return $defaults;
}



add_action('admin_print_styles', 'kimono_my_admin_print_styles');
function kimono_my_admin_print_styles() {
  wp_enqueue_style( 'farbtastic' );
}
add_action('admin_enqueue_scripts', 'kimono_my_admin_enqueue_scripts');
function kimono_my_admin_enqueue_scripts() {
  wp_enqueue_script( 'farbtastic' );
  wp_enqueue_script( 'quicktags' );
  wp_enqueue_script( 'my-admin-script', get_stylesheet_directory_uri() . '/admin-script.js', array( 'farbtastic', 'quicktags' ), false, true );
}



// kimono_fc_settings_page() displays the page content for the Header and Footer Commander submenu
function kimono_fc_settings_page() {

	//must check that the user has the required capability 
	if (!current_user_can('edit_theme_options')) {

	}
        
	//checks to see if empty then populates values


	// See if the user has posted us some information
	// If they did, this hidden field will be set to 'Y'

	if( isset($_POST[ $hidden_field_name ]) && $_POST[ $hidden_field_name ] == 'Y' ) {
 
}
?>

</form>
<?php }


function kimono_paginate() {
    global $wp_query;

    $big = 999999999;

    // http://codex.wordpress.org/Function_Reference/paginate_links
    $paginate_links = paginate_links( array(
        'base' => str_replace( $big, '%#%', get_pagenum_link($big) ),
        'current' => max( 1, get_query_var('paged') ),
        'total' => $wp_query->max_num_pages,
        'mid_size' => 5
    ) );

    if ( $paginate_links ) {
        echo '<div class="pagination">';
        echo $paginate_links;
        echo '</div><!--// end .pagination -->';
    }
}

function kimono_scriptsMore(){
	wp_enqueue_script('jquery');
	wp_enqueue_script( 'script', get_stylesheet_directory_uri() . '/js/more.js' );
}
add_action( 'admin_enqueue_scripts', 'kimono_scriptsMore' );

add_action('appearance_page_more', 'regist_more_css');
function regist_more_css() { ?>
<link rel='stylesheet' id='kimono_style-css'  href='<?php echo get_stylesheet_directory_uri() .'/css/more.css' ?>' type='text/css' media='all' /><?php }

//More
function kimono_menu_more() {
    $siteurl = get_option( 'siteurl' );
?>
<div class="moreWrap">
    <h2><img src="<?php echo get_stylesheet_directory_uri() .'/images/more/head_title.png' ?>" alt="WordPress Dedicated Ultraspeed Server GMO WP Clowd" ></h2>
    
    <div class="more_navigation">
    <ul>
    <li><a href="#hosting">WordPress Hosting</a></li>
    <li><a href="#themes">Themes</a></li>
    <li><a href="#plugins">Plugins</a></li>
    </ul>
    </div>
    
    
    <a id="hosting" name="hosting"></a>
    <div class="more_contents">
    
    <h3>GMO WP Cloud</h3>
    <div class="hosting">
    <a href="https://www.wpcloud.jp/en/?banner_id=themes" target="_blank"><p class="title">GMO WP Cloud</p>
    <p>GMO WP Cloud - The optimized WordPress cloud hosting service. <br>
    WordPress made it possible for you to build powerful websites without requiring coding skills. <br>  
    GMO WP Cloud features safe yet seamless WordPress site building experience to let you focus on site your content creation process.</p>
    <p class="more">View More</p></a>
    </div>
    
    
    <a id="themes" name="themes"></a>
    <h3>WordPress Themes</h3>
    
    <div class="themes">
    
    <div class="lead">
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/themes_tidy.jpg' ?>" alt="tidy">
    <ul>
    <li><a href="https://wordpress.org/themes/tidy " class="download" target="_blank">Free Download</a></li>
    <li><a href="http://tidy.wpcloud.net/" class="demo" target="_blank">View Demo</a></li>
    </ul>
    <h4>Tidy</h4>
    <p>Tidy is a multi-purpose WordPress theme with ultimate simplicity. It is fully customizable, responsive and flexible.  Contents can be turned on and off as desired, and a wide variety of layout options to help you build a satisfactory website. The theme supports original slider, social media integration, Google advertisement & stats plugins along with the web font support with full color customization for enhanced flexibility.</p>
    </div>
    
	<div class="lead">
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/themes_madeini.jpg' ?>" alt="Madeini">
    <ul>
    <li><a href="http://wordpress.org/themes/madeini" class="download" target="_blank">Free Download</a></li>
    <li><a href="http://madeini.wpcloud.net/" class="demo" target="_blank">View Demo</a></li>
    </ul>
    <h4>Madeini</h4>
    <p>Madeini is an upgraded version of Twenty Fourteen WordPress default theme with enhanced custom color and custom background image feature.  Enlarged homepage image makes it suitable for photography websites.</p>
    </div>

    <div>
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/themes_kimono.jpg' ?>" alt="Kimono">
    <ul>
    <li><a href="http://wordpress.org/themes/kimono" class="download" target="_blank">Free Download</a></li>
    <li><a href="http://kimono.wpcloud.net/" class="demo" target="_blank">View Demo</a></li>
    </ul>
    <h4>Kimono</h4>
    <p>Kimono is a simple, and user friendly WordPress theme that is focused on design. Its beautiful design inspiration comes from Japanese traditional garment called Kimono.  Slider is standard in this theme therefore no plugin or complicated setup is required.</p>
    </div>

    <div>
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/themes_kotenhanagara.jpg' ?>" alt="Kotenhanagara">
    <ul>
    <li><a href="http://wordpress.org/themes/kotenhanagara" class="download" target="_blank">Free Download</a></li>
    <li><a href="http://kotenhanagara.wpcloud.net/" class="demo" target="_blank">View Demo</a></li>
    </ul>
    <h4>Kotenhanagara</h4>
    <p>Kotenhanagara is a simple, easy-to-use and highly customizable WordPress theme. Beautiful design inspiration came from Japanese Urushi lacqerware, varnished with the traditional manners.  Background color can be customized as well as swappable flower patterned default background.</p>
    </div>

    <div>
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/themes_de_naani.jpg' ?>" alt="de naani.">
    <ul>
    <li><a href="https://wordpress.org/themes/de-naani" class="download" target="_blank">Free Download</a></li>
    <li><a href="http://denaani.wpcloud.net/" class="demo" target="_blank">View Demo</a></li>
    </ul>
    <h4>de naani.</h4>
    <p>'de naani.' is an upgraded version of Twenty-Twelve default theme which is designed to work perfectly with 'GMO Show Time' slider plugin and 'GMO Font agent'web font plugin. This theme also allow you to insert logo, and change site title/tagline positions.</p>
    </div>

    <div>
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/themes_azabu_juban.jpg' ?>" alt="Azabu Juban">
    <ul>
    <li><a href="http://wordpress.org/themes/azabu-juban" class="download" target="_blank">Free Download</a></li>
    <li><a href="http://azabujuban.wpcloud.net/" class="demo" target="_blank">View Demo</a></li>
    </ul>
    <h4>Azabu Juban</h4>
    <p>Azabu Juban is an upgraded version of Twenty Fourteen WordPress default theme, which is simple, easy-to-use and highly customizable. This theme features numbers of beautiful design templates with traditional Japanese taste which gives your website a unique look.</p>
    </div>

    
    </div>
    
    
    <a id="plugins" name="plugins"></a>
    <h3>Plugins</h3>
    
    <div class="plugins">
    
    <div class="plugins_detail">
    <div class="plugins_detail_l">
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/ico_plugin_showtime.gif' ?>">
    <p class="link"><a href="https://wordpress.org/plugins/gmo-showtime/" target="_blank">Free Download</a></p>
    </div>
    <div class="plugins_detail_r">
    <h4>GMO Showtime</h4>
    <p>GMO Showtime slider plugin gives cool effects to the slider in a snap. The control screen is simple, for anyone to easily use. Express user's originality with fully customizable link and color as well as 16 slider effects in 6 different layouts.</p>
    </div>
    </div>
    
    <div class="plugins_detail">
    <div class="plugins_detail_l">
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/ico_plugin_font_agent.gif' ?>">
    <p class="link"><a href="https://wordpress.org/plugins/gmo-font-agent/" target="_blank">Free Download</a></p>
    </div>
    <div class="plugins_detail_r">
    <h4>GMO Font Agent</h4>
    <p>GMO Font Agent plugin works with Google fonts, gives you a choice to use variety of stylish web fonts. The plugin is genericon and IcoMoon compatible, to enhance its usability. Icons can be inserted from the post editor.</p>
    </div>
    </div>

    <div class="plugins_detail">
    <div class="plugins_detail_l">
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/ico_plugin_sahre_connection.gif' ?>">
    <p class="link"><a href="https://wordpress.org/plugins/gmo-share-connection/" target="_blank">Free Download</a></p>
    </div>
    <div class="plugins_detail_r">
    <h4>GMO Share Connection</h4>
    <p>GMO Share Connection plugin is designed for easy social sharing by letting user choose place/pages to use icons. 9 social network services are supported in this plugin including Facebook and Twitter.</p>
    </div>
    </div>

    <div class="plugins_detail">
    <div class="plugins_detail_l">
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/ico_plugin_ads_master.gif' ?>">
    <p class="link"><a href="https://wordpress.org/plugins/gmo-ads-master/" target="_blank">Free Download</a></p>
    </div>
    <div class="plugins_detail_r">
    <h4>GMO Ads Master</h4>
    <p>GMO Ads Master is the ad banner plugin which enables you to place ad contents to the desired locations such as inside article, sidebar and footer. In addition to that, using this plugin let you setup Google Analytics tracking code and sitemap tool settings, and sitemap can be easily generated without playing with PHP files.</p>
    </div>
    </div>

    <div class="plugins_detail">
    <div class="plugins_detail_l">
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/ico_plugin_go_to_top.gif' ?>">
    <p class="link"><a href="https://wordpress.org/plugins/gmo-go-to-top/" target="_blank">Free Download</a></p>
    </div>
    <div class="plugins_detail_r">
    <h4>GMO Go to Top</h4>
    <p>GMO Go to Top is a simple plugin adds a simple button which allows users to scroll all the way up to the top by 1-click.  Button color, style, position can be modified or you can also upload your own button image.</p>
    </div>
    </div>

    <div class="plugins_detail">
    <div class="plugins_detail_l">
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/ico_plugin_page_trasitions.gif' ?>">
    <p class="link"><a href="https://wordpress.org/plugins/gmo-page-transitions/" target="_blank">Free Download</a></p>
    </div>
    <div class="plugins_detail_r">
    <h4>GMO Page Transitions</h4>
    <p>GMO Page Transitions adds Page Transitions actions to your site. Click on the link, and page will slide over to left or right. This effect will not apply when "target=_brank" is used.</p>
    </div>
    </div>

    <div class="plugins_detail">
    <div class="plugins_detail_l">
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/ico_plugin_tinymce_smiley.gif' ?>">
    <p class="link"><a href="https://wordpress.org/plugins/gmo-tinymce-smiley/" target="_blank">Free Download</a></p>
    </div>
    <div class="plugins_detail_r">
    <h4>GMO TinyMCE Smiley</h4>
    <p>GMO TinyMCE Smiley is a plugin to let you instantly add smilies into your site from the toolbar..</p>
    </div>
    </div>

    <div class="plugins_detail">
    <div class="plugins_detail_l">
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/ico_plugin_google_map.gif' ?>">
    <p class="link"><a href="https://wordpress.org/plugins/gmo-google-map/" target="_blank">Free Download</a></p>
    </div>
    <div class="plugins_detail_r">
    <h4>GMO Google Map</h4>
    <p>With "GMO Google Map" plugin, you can use Google Maps on your website by simply embedding a shortcode in anywhere you desire. No special coding skill is required. Simply enter information (eg. address) to create a shortcode and paste it to complete.</p>
    </div>
    </div>
    
    <div class="plugins_detail">
    <div class="plugins_detail_l">
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/ico_plugin_showtime.gif' ?>">
    <p class="link"><a href="https://wordpress.org/plugins/gmo-widget-custom/" target="_blank">Free Download</a></p>
    </div>
    <div class="plugins_detail_r">
    <h4>GMO Widget Custom</h4>
    <p>This is a useful widget customizer plugin which enables you to insert images, ad and recommendation banners.</p>
    </div>
    </div>

    <div class="plugins_detail">
    <div class="plugins_detail_l">
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/ico_plugin_slider.gif' ?>">
    <p class="link"><a href="https://wordpress.org/plugins/gmo-slider/" target="_blank">Free Download</a></p>
    </div>
    <div class="plugins_detail_r">
    <h4>GMO Slider</h4>
    <p>GMO Slider plugin let you insert sliders in posts and pages. The control screen is simple, for anyone to easily use. GMO Slider supports images as well as text and video.  </p>
    </div>
    </div>

    <div class="plugins_detail">
    <div class="plugins_detail_l">
    <img src="<?php echo get_stylesheet_directory_uri() .'/images/more/ico_plugin_social_connection.gif' ?>">
    <p class="link"><a href="https://wordpress.org/plugins/gmo-social-connection/" target="_blank">Free Download</a></p>
    </div>
    <div class="plugins_detail_r">
    <h4>GMO Social Connection</h4>
    <p>GMO Social Connection let you easily place SNS share buttons on the articles. It also allows you to choose button position from top or bottom. Supported SNS are Facebook, Twitter and Google+.</p>
    </div>
    </div>
    
    
    </div>
    
    </div>
    
    
    <div class="quality">
    <h3>Quality Service</h3>
    <p class="lead">“Brought to you by Japan's leading one-stop provider of Internet services”</p>
    <p><img src="<?php echo get_stylesheet_directory_uri() .'/images/more/footer_logo_gmo.png' ?>" alt="GMO INTERNET GROUP" ></p>
    <p>GMO WP Cloud is operated by GMO Internet group, the number one provider of domain registration, web hosting, security, ecommerce and payment processing solutions in Japan.Under the corporate slogan "Internet for Everyone", GMO Internet Group's trusted service brand represents industry expertise, a proven track record and quality service.</p>
    <p><a href="http://www.gmo.jp/en/" target="_blank">> Visit GMO Internet Group</a></p>
    </div>
    
</div>
<?php
}
function kimono_admin_menu() {
    add_theme_page( 'GMO WP Clowd', 'More', 'read','more', 'kimono_menu_more' );
}

add_action( 'admin_menu', 'kimono_admin_menu' );

//Dashboard
function kimono_dashboard_widget_function() {
?>
<a href="https://www.wpcloud.jp/en/?banner_id=themes" target="_blank"><img src="<?php echo get_stylesheet_directory_uri() .'/images/300250_wpcloud_0001.gif' ?>" style="width:100%"></a>
<?php
}
function kimono_add_dashboard_widgets() {
wp_add_dashboard_widget('kimono_dashboard_widget', 'GMO WP Cloud', 'kimono_dashboard_widget_function');
global $wp_meta_boxes;
$normal_dashboard = $wp_meta_boxes['dashboard']['normal']['core'];
$example_widget_backup = array('kimono_dashboard_widget' => $normal_dashboard['kimono_dashboard_widget']);
unset($normal_dashboard['kimono_dashboard_widget']);
$sorted_dashboard = array_merge($example_widget_backup, $normal_dashboard);
$wp_meta_boxes['dashboard']['normal']['core'] = $sorted_dashboard;
}
add_action('wp_dashboard_setup', 'kimono_add_dashboard_widgets' );
?>
